from ...google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from ...openapiv3 import annotations_pb2 as _annotations_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AppKey(_message.Message):
    __slots__ = ["created_at", "created_by", "description", "id", "name", "project", "secret", "updated_at", "updated_by"]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    created_at: int
    created_by: str
    description: str
    id: str
    name: str
    project: str
    secret: str
    updated_at: int
    updated_by: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., secret: _Optional[str] = ..., created_at: _Optional[int] = ..., created_by: _Optional[str] = ..., updated_at: _Optional[int] = ..., updated_by: _Optional[str] = ..., project: _Optional[str] = ...) -> None: ...

class BeginTransactionRequest(_message.Message):
    __slots__ = ["branch", "options", "project"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    options: TransactionOptions
    project: str
    def __init__(self, project: _Optional[str] = ..., options: _Optional[_Union[TransactionOptions, _Mapping]] = ..., branch: _Optional[str] = ...) -> None: ...

class BeginTransactionResponse(_message.Message):
    __slots__ = ["tx_ctx"]
    TX_CTX_FIELD_NUMBER: _ClassVar[int]
    tx_ctx: TransactionCtx
    def __init__(self, tx_ctx: _Optional[_Union[TransactionCtx, _Mapping]] = ...) -> None: ...

class BranchInfo(_message.Message):
    __slots__ = ["branch", "metadata"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    branch: str
    metadata: BranchMetadata
    def __init__(self, branch: _Optional[str] = ..., metadata: _Optional[_Union[BranchMetadata, _Mapping]] = ...) -> None: ...

class BranchMetadata(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class BuildCollectionIndexRequest(_message.Message):
    __slots__ = ["branch", "collection", "project"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    collection: str
    project: str
    def __init__(self, project: _Optional[str] = ..., collection: _Optional[str] = ..., branch: _Optional[str] = ...) -> None: ...

class BuildCollectionIndexResponse(_message.Message):
    __slots__ = ["indexes"]
    INDEXES_FIELD_NUMBER: _ClassVar[int]
    indexes: _containers.RepeatedCompositeFieldContainer[CollectionIndex]
    def __init__(self, indexes: _Optional[_Iterable[_Union[CollectionIndex, _Mapping]]] = ...) -> None: ...

class Collation(_message.Message):
    __slots__ = ["case"]
    CASE_FIELD_NUMBER: _ClassVar[int]
    case: str
    def __init__(self, case: _Optional[str] = ...) -> None: ...

class CollectionDescription(_message.Message):
    __slots__ = ["collection", "indexes", "metadata", "schema", "size"]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    INDEXES_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    collection: str
    indexes: _containers.RepeatedCompositeFieldContainer[CollectionIndex]
    metadata: CollectionMetadata
    schema: bytes
    size: int
    def __init__(self, collection: _Optional[str] = ..., metadata: _Optional[_Union[CollectionMetadata, _Mapping]] = ..., schema: _Optional[bytes] = ..., size: _Optional[int] = ..., indexes: _Optional[_Iterable[_Union[CollectionIndex, _Mapping]]] = ...) -> None: ...

class CollectionIndex(_message.Message):
    __slots__ = ["fields", "name", "state"]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    fields: _containers.RepeatedCompositeFieldContainer[Field]
    name: str
    state: str
    def __init__(self, name: _Optional[str] = ..., state: _Optional[str] = ..., fields: _Optional[_Iterable[_Union[Field, _Mapping]]] = ...) -> None: ...

class CollectionInfo(_message.Message):
    __slots__ = ["collection", "metadata"]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    collection: str
    metadata: CollectionMetadata
    def __init__(self, collection: _Optional[str] = ..., metadata: _Optional[_Union[CollectionMetadata, _Mapping]] = ...) -> None: ...

class CollectionMetadata(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CollectionOptions(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CommitTransactionRequest(_message.Message):
    __slots__ = ["branch", "project"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    project: str
    def __init__(self, project: _Optional[str] = ..., branch: _Optional[str] = ...) -> None: ...

class CommitTransactionResponse(_message.Message):
    __slots__ = ["status"]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: str
    def __init__(self, status: _Optional[str] = ...) -> None: ...

class CountRequest(_message.Message):
    __slots__ = ["branch", "collection", "filter", "project"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    collection: str
    filter: bytes
    project: str
    def __init__(self, project: _Optional[str] = ..., collection: _Optional[str] = ..., filter: _Optional[bytes] = ..., branch: _Optional[str] = ...) -> None: ...

class CountResponse(_message.Message):
    __slots__ = ["count"]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    count: int
    def __init__(self, count: _Optional[int] = ...) -> None: ...

class CreateAppKeyRequest(_message.Message):
    __slots__ = ["description", "name", "project"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    description: str
    name: str
    project: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., project: _Optional[str] = ...) -> None: ...

class CreateAppKeyResponse(_message.Message):
    __slots__ = ["created_app_key"]
    CREATED_APP_KEY_FIELD_NUMBER: _ClassVar[int]
    created_app_key: AppKey
    def __init__(self, created_app_key: _Optional[_Union[AppKey, _Mapping]] = ...) -> None: ...

class CreateBranchRequest(_message.Message):
    __slots__ = ["branch", "project"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    project: str
    def __init__(self, project: _Optional[str] = ..., branch: _Optional[str] = ...) -> None: ...

class CreateBranchResponse(_message.Message):
    __slots__ = ["message", "status"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    message: str
    status: str
    def __init__(self, message: _Optional[str] = ..., status: _Optional[str] = ...) -> None: ...

class CreateOrUpdateCollectionRequest(_message.Message):
    __slots__ = ["branch", "collection", "only_create", "options", "project", "schema"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    ONLY_CREATE_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    branch: str
    collection: str
    only_create: bool
    options: CollectionOptions
    project: str
    schema: bytes
    def __init__(self, project: _Optional[str] = ..., collection: _Optional[str] = ..., schema: _Optional[bytes] = ..., only_create: bool = ..., options: _Optional[_Union[CollectionOptions, _Mapping]] = ..., branch: _Optional[str] = ...) -> None: ...

class CreateOrUpdateCollectionResponse(_message.Message):
    __slots__ = ["message", "status"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    message: str
    status: str
    def __init__(self, message: _Optional[str] = ..., status: _Optional[str] = ...) -> None: ...

class CreateProjectRequest(_message.Message):
    __slots__ = ["project"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: str
    def __init__(self, project: _Optional[str] = ...) -> None: ...

class CreateProjectResponse(_message.Message):
    __slots__ = ["message", "status"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    message: str
    status: str
    def __init__(self, message: _Optional[str] = ..., status: _Optional[str] = ...) -> None: ...

class DatabaseMetadata(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DatabaseOptions(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteAppKeyRequest(_message.Message):
    __slots__ = ["id", "project"]
    ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    id: str
    project: str
    def __init__(self, id: _Optional[str] = ..., project: _Optional[str] = ...) -> None: ...

class DeleteAppKeyResponse(_message.Message):
    __slots__ = ["deleted"]
    DELETED_FIELD_NUMBER: _ClassVar[int]
    deleted: bool
    def __init__(self, deleted: bool = ...) -> None: ...

class DeleteBranchRequest(_message.Message):
    __slots__ = ["branch", "project"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    project: str
    def __init__(self, project: _Optional[str] = ..., branch: _Optional[str] = ...) -> None: ...

class DeleteBranchResponse(_message.Message):
    __slots__ = ["message", "status"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    message: str
    status: str
    def __init__(self, message: _Optional[str] = ..., status: _Optional[str] = ...) -> None: ...

class DeleteProjectRequest(_message.Message):
    __slots__ = ["project"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: str
    def __init__(self, project: _Optional[str] = ...) -> None: ...

class DeleteProjectResponse(_message.Message):
    __slots__ = ["message", "status"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    message: str
    status: str
    def __init__(self, message: _Optional[str] = ..., status: _Optional[str] = ...) -> None: ...

class DeleteRequest(_message.Message):
    __slots__ = ["branch", "collection", "filter", "options", "project"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    collection: str
    filter: bytes
    options: DeleteRequestOptions
    project: str
    def __init__(self, project: _Optional[str] = ..., collection: _Optional[str] = ..., filter: _Optional[bytes] = ..., options: _Optional[_Union[DeleteRequestOptions, _Mapping]] = ..., branch: _Optional[str] = ...) -> None: ...

class DeleteRequestOptions(_message.Message):
    __slots__ = ["collation", "limit", "write_options"]
    COLLATION_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    WRITE_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    collation: Collation
    limit: int
    write_options: WriteOptions
    def __init__(self, write_options: _Optional[_Union[WriteOptions, _Mapping]] = ..., collation: _Optional[_Union[Collation, _Mapping]] = ..., limit: _Optional[int] = ...) -> None: ...

class DeleteResponse(_message.Message):
    __slots__ = ["deleted_count", "metadata", "status"]
    DELETED_COUNT_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    deleted_count: int
    metadata: ResponseMetadata
    status: str
    def __init__(self, metadata: _Optional[_Union[ResponseMetadata, _Mapping]] = ..., status: _Optional[str] = ..., deleted_count: _Optional[int] = ...) -> None: ...

class DescribeCollectionRequest(_message.Message):
    __slots__ = ["branch", "collection", "options", "project", "schema_format"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FORMAT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    collection: str
    options: CollectionOptions
    project: str
    schema_format: str
    def __init__(self, project: _Optional[str] = ..., collection: _Optional[str] = ..., schema_format: _Optional[str] = ..., options: _Optional[_Union[CollectionOptions, _Mapping]] = ..., branch: _Optional[str] = ...) -> None: ...

class DescribeCollectionResponse(_message.Message):
    __slots__ = ["collection", "indexes", "metadata", "schema", "size"]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    INDEXES_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    collection: str
    indexes: _containers.RepeatedCompositeFieldContainer[CollectionIndex]
    metadata: CollectionMetadata
    schema: bytes
    size: int
    def __init__(self, collection: _Optional[str] = ..., metadata: _Optional[_Union[CollectionMetadata, _Mapping]] = ..., schema: _Optional[bytes] = ..., size: _Optional[int] = ..., indexes: _Optional[_Iterable[_Union[CollectionIndex, _Mapping]]] = ...) -> None: ...

class DescribeDatabaseRequest(_message.Message):
    __slots__ = ["branch", "project", "schema_format"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FORMAT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    project: str
    schema_format: str
    def __init__(self, project: _Optional[str] = ..., schema_format: _Optional[str] = ..., branch: _Optional[str] = ...) -> None: ...

class DescribeDatabaseResponse(_message.Message):
    __slots__ = ["branches", "collections", "metadata", "size"]
    BRANCHES_FIELD_NUMBER: _ClassVar[int]
    COLLECTIONS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    branches: _containers.RepeatedScalarFieldContainer[str]
    collections: _containers.RepeatedCompositeFieldContainer[CollectionDescription]
    metadata: DatabaseMetadata
    size: int
    def __init__(self, metadata: _Optional[_Union[DatabaseMetadata, _Mapping]] = ..., collections: _Optional[_Iterable[_Union[CollectionDescription, _Mapping]]] = ..., size: _Optional[int] = ..., branches: _Optional[_Iterable[str]] = ...) -> None: ...

class DropCollectionRequest(_message.Message):
    __slots__ = ["branch", "collection", "options", "project"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    collection: str
    options: CollectionOptions
    project: str
    def __init__(self, project: _Optional[str] = ..., collection: _Optional[str] = ..., options: _Optional[_Union[CollectionOptions, _Mapping]] = ..., branch: _Optional[str] = ...) -> None: ...

class DropCollectionResponse(_message.Message):
    __slots__ = ["message", "status"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    message: str
    status: str
    def __init__(self, message: _Optional[str] = ..., status: _Optional[str] = ...) -> None: ...

class ExplainResponse(_message.Message):
    __slots__ = ["collection", "field", "filter", "key_range", "read_type", "sorting"]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    KEY_RANGE_FIELD_NUMBER: _ClassVar[int]
    READ_TYPE_FIELD_NUMBER: _ClassVar[int]
    SORTING_FIELD_NUMBER: _ClassVar[int]
    collection: str
    field: str
    filter: str
    key_range: _containers.RepeatedScalarFieldContainer[str]
    read_type: str
    sorting: str
    def __init__(self, collection: _Optional[str] = ..., read_type: _Optional[str] = ..., filter: _Optional[str] = ..., sorting: _Optional[str] = ..., key_range: _Optional[_Iterable[str]] = ..., field: _Optional[str] = ...) -> None: ...

class FacetCount(_message.Message):
    __slots__ = ["count", "value"]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    count: int
    value: str
    def __init__(self, count: _Optional[int] = ..., value: _Optional[str] = ...) -> None: ...

class FacetStats(_message.Message):
    __slots__ = ["avg", "count", "max", "min", "sum"]
    AVG_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    MAX_FIELD_NUMBER: _ClassVar[int]
    MIN_FIELD_NUMBER: _ClassVar[int]
    SUM_FIELD_NUMBER: _ClassVar[int]
    avg: float
    count: int
    max: float
    min: float
    sum: float
    def __init__(self, avg: _Optional[float] = ..., max: _Optional[float] = ..., min: _Optional[float] = ..., sum: _Optional[float] = ..., count: _Optional[int] = ...) -> None: ...

class Field(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GroupedSearchHits(_message.Message):
    __slots__ = ["group_keys", "hits"]
    GROUP_KEYS_FIELD_NUMBER: _ClassVar[int]
    HITS_FIELD_NUMBER: _ClassVar[int]
    group_keys: _containers.RepeatedScalarFieldContainer[str]
    hits: _containers.RepeatedCompositeFieldContainer[SearchHit]
    def __init__(self, group_keys: _Optional[_Iterable[str]] = ..., hits: _Optional[_Iterable[_Union[SearchHit, _Mapping]]] = ...) -> None: ...

class ImportRequest(_message.Message):
    __slots__ = ["autogenerated", "branch", "collection", "create_collection", "documents", "options", "primary_key", "project"]
    AUTOGENERATED_FIELD_NUMBER: _ClassVar[int]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    CREATE_COLLECTION_FIELD_NUMBER: _ClassVar[int]
    DOCUMENTS_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PRIMARY_KEY_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    autogenerated: _containers.RepeatedScalarFieldContainer[str]
    branch: str
    collection: str
    create_collection: bool
    documents: _containers.RepeatedScalarFieldContainer[bytes]
    options: ImportRequestOptions
    primary_key: _containers.RepeatedScalarFieldContainer[str]
    project: str
    def __init__(self, project: _Optional[str] = ..., collection: _Optional[str] = ..., documents: _Optional[_Iterable[bytes]] = ..., options: _Optional[_Union[ImportRequestOptions, _Mapping]] = ..., branch: _Optional[str] = ..., create_collection: bool = ..., primary_key: _Optional[_Iterable[str]] = ..., autogenerated: _Optional[_Iterable[str]] = ...) -> None: ...

class ImportRequestOptions(_message.Message):
    __slots__ = ["write_options"]
    WRITE_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    write_options: WriteOptions
    def __init__(self, write_options: _Optional[_Union[WriteOptions, _Mapping]] = ...) -> None: ...

class ImportResponse(_message.Message):
    __slots__ = ["keys", "metadata", "status"]
    KEYS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    keys: _containers.RepeatedScalarFieldContainer[bytes]
    metadata: ResponseMetadata
    status: str
    def __init__(self, metadata: _Optional[_Union[ResponseMetadata, _Mapping]] = ..., status: _Optional[str] = ..., keys: _Optional[_Iterable[bytes]] = ...) -> None: ...

class InsertRequest(_message.Message):
    __slots__ = ["branch", "collection", "documents", "options", "project"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    DOCUMENTS_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    collection: str
    documents: _containers.RepeatedScalarFieldContainer[bytes]
    options: InsertRequestOptions
    project: str
    def __init__(self, project: _Optional[str] = ..., collection: _Optional[str] = ..., documents: _Optional[_Iterable[bytes]] = ..., options: _Optional[_Union[InsertRequestOptions, _Mapping]] = ..., branch: _Optional[str] = ...) -> None: ...

class InsertRequestOptions(_message.Message):
    __slots__ = ["write_options"]
    WRITE_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    write_options: WriteOptions
    def __init__(self, write_options: _Optional[_Union[WriteOptions, _Mapping]] = ...) -> None: ...

class InsertResponse(_message.Message):
    __slots__ = ["keys", "metadata", "status"]
    KEYS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    keys: _containers.RepeatedScalarFieldContainer[bytes]
    metadata: ResponseMetadata
    status: str
    def __init__(self, metadata: _Optional[_Union[ResponseMetadata, _Mapping]] = ..., status: _Optional[str] = ..., keys: _Optional[_Iterable[bytes]] = ...) -> None: ...

class ListAppKeysRequest(_message.Message):
    __slots__ = ["project"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: str
    def __init__(self, project: _Optional[str] = ...) -> None: ...

class ListAppKeysResponse(_message.Message):
    __slots__ = ["app_keys"]
    APP_KEYS_FIELD_NUMBER: _ClassVar[int]
    app_keys: _containers.RepeatedCompositeFieldContainer[AppKey]
    def __init__(self, app_keys: _Optional[_Iterable[_Union[AppKey, _Mapping]]] = ...) -> None: ...

class ListBranchesRequest(_message.Message):
    __slots__ = ["project"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: str
    def __init__(self, project: _Optional[str] = ...) -> None: ...

class ListBranchesResponse(_message.Message):
    __slots__ = ["branches"]
    BRANCHES_FIELD_NUMBER: _ClassVar[int]
    branches: _containers.RepeatedCompositeFieldContainer[BranchInfo]
    def __init__(self, branches: _Optional[_Iterable[_Union[BranchInfo, _Mapping]]] = ...) -> None: ...

class ListCollectionsRequest(_message.Message):
    __slots__ = ["branch", "options", "project"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    options: CollectionOptions
    project: str
    def __init__(self, project: _Optional[str] = ..., options: _Optional[_Union[CollectionOptions, _Mapping]] = ..., branch: _Optional[str] = ...) -> None: ...

class ListCollectionsResponse(_message.Message):
    __slots__ = ["collections"]
    COLLECTIONS_FIELD_NUMBER: _ClassVar[int]
    collections: _containers.RepeatedCompositeFieldContainer[CollectionInfo]
    def __init__(self, collections: _Optional[_Iterable[_Union[CollectionInfo, _Mapping]]] = ...) -> None: ...

class ListProjectsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListProjectsResponse(_message.Message):
    __slots__ = ["projects"]
    PROJECTS_FIELD_NUMBER: _ClassVar[int]
    projects: _containers.RepeatedCompositeFieldContainer[ProjectInfo]
    def __init__(self, projects: _Optional[_Iterable[_Union[ProjectInfo, _Mapping]]] = ...) -> None: ...

class Match(_message.Message):
    __slots__ = ["fields", "score", "vector_distance"]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    VECTOR_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    fields: _containers.RepeatedCompositeFieldContainer[MatchField]
    score: str
    vector_distance: float
    def __init__(self, fields: _Optional[_Iterable[_Union[MatchField, _Mapping]]] = ..., score: _Optional[str] = ..., vector_distance: _Optional[float] = ...) -> None: ...

class MatchField(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class Page(_message.Message):
    __slots__ = ["current", "size"]
    CURRENT_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    current: int
    size: int
    def __init__(self, current: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class ProjectDescription(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ProjectInfo(_message.Message):
    __slots__ = ["metadata", "project"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    metadata: ProjectMetadata
    project: str
    def __init__(self, project: _Optional[str] = ..., metadata: _Optional[_Union[ProjectMetadata, _Mapping]] = ...) -> None: ...

class ProjectMetadata(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ReadRequest(_message.Message):
    __slots__ = ["branch", "collection", "fields", "filter", "options", "project", "sort"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    collection: str
    fields: bytes
    filter: bytes
    options: ReadRequestOptions
    project: str
    sort: bytes
    def __init__(self, project: _Optional[str] = ..., collection: _Optional[str] = ..., filter: _Optional[bytes] = ..., fields: _Optional[bytes] = ..., options: _Optional[_Union[ReadRequestOptions, _Mapping]] = ..., sort: _Optional[bytes] = ..., branch: _Optional[str] = ...) -> None: ...

class ReadRequestOptions(_message.Message):
    __slots__ = ["collation", "limit", "offset", "skip"]
    COLLATION_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SKIP_FIELD_NUMBER: _ClassVar[int]
    collation: Collation
    limit: int
    offset: bytes
    skip: int
    def __init__(self, limit: _Optional[int] = ..., skip: _Optional[int] = ..., offset: _Optional[bytes] = ..., collation: _Optional[_Union[Collation, _Mapping]] = ...) -> None: ...

class ReadResponse(_message.Message):
    __slots__ = ["data", "metadata", "resume_token"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    RESUME_TOKEN_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    metadata: ResponseMetadata
    resume_token: bytes
    def __init__(self, data: _Optional[bytes] = ..., resume_token: _Optional[bytes] = ..., metadata: _Optional[_Union[ResponseMetadata, _Mapping]] = ...) -> None: ...

class ReplaceRequest(_message.Message):
    __slots__ = ["branch", "collection", "documents", "options", "project"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    DOCUMENTS_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    collection: str
    documents: _containers.RepeatedScalarFieldContainer[bytes]
    options: ReplaceRequestOptions
    project: str
    def __init__(self, project: _Optional[str] = ..., collection: _Optional[str] = ..., documents: _Optional[_Iterable[bytes]] = ..., options: _Optional[_Union[ReplaceRequestOptions, _Mapping]] = ..., branch: _Optional[str] = ...) -> None: ...

class ReplaceRequestOptions(_message.Message):
    __slots__ = ["write_options"]
    WRITE_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    write_options: WriteOptions
    def __init__(self, write_options: _Optional[_Union[WriteOptions, _Mapping]] = ...) -> None: ...

class ReplaceResponse(_message.Message):
    __slots__ = ["keys", "metadata", "status"]
    KEYS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    keys: _containers.RepeatedScalarFieldContainer[bytes]
    metadata: ResponseMetadata
    status: str
    def __init__(self, metadata: _Optional[_Union[ResponseMetadata, _Mapping]] = ..., status: _Optional[str] = ..., keys: _Optional[_Iterable[bytes]] = ...) -> None: ...

class ResponseMetadata(_message.Message):
    __slots__ = ["created_at", "deleted_at", "updated_at"]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    DELETED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    created_at: _timestamp_pb2.Timestamp
    deleted_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., deleted_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class RollbackTransactionRequest(_message.Message):
    __slots__ = ["branch", "project"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    project: str
    def __init__(self, project: _Optional[str] = ..., branch: _Optional[str] = ...) -> None: ...

class RollbackTransactionResponse(_message.Message):
    __slots__ = ["status"]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: str
    def __init__(self, status: _Optional[str] = ...) -> None: ...

class RotateAppKeyRequest(_message.Message):
    __slots__ = ["id", "project"]
    ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    id: str
    project: str
    def __init__(self, id: _Optional[str] = ..., project: _Optional[str] = ...) -> None: ...

class RotateAppKeyResponse(_message.Message):
    __slots__ = ["app_key"]
    APP_KEY_FIELD_NUMBER: _ClassVar[int]
    app_key: AppKey
    def __init__(self, app_key: _Optional[_Union[AppKey, _Mapping]] = ...) -> None: ...

class SearchFacet(_message.Message):
    __slots__ = ["counts", "stats"]
    COUNTS_FIELD_NUMBER: _ClassVar[int]
    STATS_FIELD_NUMBER: _ClassVar[int]
    counts: _containers.RepeatedCompositeFieldContainer[FacetCount]
    stats: FacetStats
    def __init__(self, counts: _Optional[_Iterable[_Union[FacetCount, _Mapping]]] = ..., stats: _Optional[_Union[FacetStats, _Mapping]] = ...) -> None: ...

class SearchHit(_message.Message):
    __slots__ = ["data", "metadata"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    metadata: SearchHitMeta
    def __init__(self, data: _Optional[bytes] = ..., metadata: _Optional[_Union[SearchHitMeta, _Mapping]] = ...) -> None: ...

class SearchHitMeta(_message.Message):
    __slots__ = ["created_at", "match", "updated_at"]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    MATCH_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    created_at: _timestamp_pb2.Timestamp
    match: Match
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., match: _Optional[_Union[Match, _Mapping]] = ...) -> None: ...

class SearchMetadata(_message.Message):
    __slots__ = ["found", "matched_fields", "page", "total_pages"]
    FOUND_FIELD_NUMBER: _ClassVar[int]
    MATCHED_FIELDS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    TOTAL_PAGES_FIELD_NUMBER: _ClassVar[int]
    found: int
    matched_fields: _containers.RepeatedScalarFieldContainer[str]
    page: Page
    total_pages: int
    def __init__(self, found: _Optional[int] = ..., total_pages: _Optional[int] = ..., page: _Optional[_Union[Page, _Mapping]] = ..., matched_fields: _Optional[_Iterable[str]] = ...) -> None: ...

class SearchRequest(_message.Message):
    __slots__ = ["branch", "collation", "collection", "exclude_fields", "facet", "filter", "group_by", "include_fields", "page", "page_size", "project", "q", "search_fields", "sort", "vector"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    COLLATION_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    EXCLUDE_FIELDS_FIELD_NUMBER: _ClassVar[int]
    FACET_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_FIELDS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    Q_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELDS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    VECTOR_FIELD_NUMBER: _ClassVar[int]
    branch: str
    collation: Collation
    collection: str
    exclude_fields: _containers.RepeatedScalarFieldContainer[str]
    facet: bytes
    filter: bytes
    group_by: bytes
    include_fields: _containers.RepeatedScalarFieldContainer[str]
    page: int
    page_size: int
    project: str
    q: str
    search_fields: _containers.RepeatedScalarFieldContainer[str]
    sort: bytes
    vector: bytes
    def __init__(self, project: _Optional[str] = ..., collection: _Optional[str] = ..., q: _Optional[str] = ..., search_fields: _Optional[_Iterable[str]] = ..., filter: _Optional[bytes] = ..., facet: _Optional[bytes] = ..., sort: _Optional[bytes] = ..., include_fields: _Optional[_Iterable[str]] = ..., exclude_fields: _Optional[_Iterable[str]] = ..., page_size: _Optional[int] = ..., page: _Optional[int] = ..., collation: _Optional[_Union[Collation, _Mapping]] = ..., branch: _Optional[str] = ..., group_by: _Optional[bytes] = ..., vector: _Optional[bytes] = ...) -> None: ...

class SearchResponse(_message.Message):
    __slots__ = ["facets", "group", "hits", "meta"]
    class FacetsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: SearchFacet
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[SearchFacet, _Mapping]] = ...) -> None: ...
    FACETS_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    HITS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    facets: _containers.MessageMap[str, SearchFacet]
    group: _containers.RepeatedCompositeFieldContainer[GroupedSearchHits]
    hits: _containers.RepeatedCompositeFieldContainer[SearchHit]
    meta: SearchMetadata
    def __init__(self, hits: _Optional[_Iterable[_Union[SearchHit, _Mapping]]] = ..., facets: _Optional[_Mapping[str, SearchFacet]] = ..., meta: _Optional[_Union[SearchMetadata, _Mapping]] = ..., group: _Optional[_Iterable[_Union[GroupedSearchHits, _Mapping]]] = ...) -> None: ...

class TransactionCtx(_message.Message):
    __slots__ = ["id", "origin"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    id: str
    origin: str
    def __init__(self, id: _Optional[str] = ..., origin: _Optional[str] = ...) -> None: ...

class TransactionOptions(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateAppKeyRequest(_message.Message):
    __slots__ = ["description", "id", "name", "project"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    description: str
    id: str
    name: str
    project: str
    def __init__(self, id: _Optional[str] = ..., project: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class UpdateAppKeyResponse(_message.Message):
    __slots__ = ["updated_app_key"]
    UPDATED_APP_KEY_FIELD_NUMBER: _ClassVar[int]
    updated_app_key: AppKey
    def __init__(self, updated_app_key: _Optional[_Union[AppKey, _Mapping]] = ...) -> None: ...

class UpdateRequest(_message.Message):
    __slots__ = ["branch", "collection", "fields", "filter", "options", "project"]
    BRANCH_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    branch: str
    collection: str
    fields: bytes
    filter: bytes
    options: UpdateRequestOptions
    project: str
    def __init__(self, project: _Optional[str] = ..., collection: _Optional[str] = ..., fields: _Optional[bytes] = ..., filter: _Optional[bytes] = ..., options: _Optional[_Union[UpdateRequestOptions, _Mapping]] = ..., branch: _Optional[str] = ...) -> None: ...

class UpdateRequestOptions(_message.Message):
    __slots__ = ["collation", "limit", "write_options"]
    COLLATION_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    WRITE_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    collation: Collation
    limit: int
    write_options: WriteOptions
    def __init__(self, write_options: _Optional[_Union[WriteOptions, _Mapping]] = ..., collation: _Optional[_Union[Collation, _Mapping]] = ..., limit: _Optional[int] = ...) -> None: ...

class UpdateResponse(_message.Message):
    __slots__ = ["metadata", "modified_count", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    MODIFIED_COUNT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: ResponseMetadata
    modified_count: int
    status: str
    def __init__(self, metadata: _Optional[_Union[ResponseMetadata, _Mapping]] = ..., modified_count: _Optional[int] = ..., status: _Optional[str] = ...) -> None: ...

class WriteOptions(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from typing import List

import grpc

from api.generated.server.v1.api_pb2 import InsertRequest, InsertResponse, ReadRequest
from api.generated.server.v1.api_pb2_grpc import TigrisStub
from tigrisdb.errors import TigrisException, TigrisServerError
from tigrisdb.types import ClientConfig, Document
from tigrisdb.utils import marshal, unmarshal


class Collection:
    __client: TigrisStub
    __config: ClientConfig
    __name: str

    def __init__(
        self, collection_name: str, client_stub: TigrisStub, config: ClientConfig
    ):
        self.__client = client_stub
        self.__config = config
        self.__name = collection_name

    @property
    def project(self):
        return self.__config.project_name

    @property
    def branch(self):
        return self.__config.branch

    @property
    def name(self):
        return self.__name

    def insert_many(self, docs: List[Document]) -> bool:
        doc_bytes = map(marshal, docs)
        req = InsertRequest(
            project=self.project,
            branch=self.branch,
            collection=self.name,
            documents=doc_bytes,
        )
        try:
            resp: InsertResponse = self.__client.Insert(req)
        except grpc.RpcError as e:
            raise TigrisServerError("failed to insert documents", e)

        if resp.status == "inserted":
            return True
        else:
            raise TigrisException(f"failed to insert docs: {resp.status}")

    def find_many(self) -> List[Document]:
        req = ReadRequest(
            project=self.project,
            branch=self.branch,
            collection=self.name,
            filter=marshal({}),
        )
        try:
            doc_iterator = self.__client.Read(req)
        except grpc.RpcError as e:
            raise TigrisServerError("failed to read documents", e)

        docs: List[Document] = []
        for r in doc_iterator:
            docs.append(unmarshal(r.data))

        return docs



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: server/v1/auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ...openapiv3 import annotations_pb2 as openapiv3_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14server/v1/auth.proto\x12\x12tigrisdata.auth.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1bopenapiv3/annotations.proto\"\x8b\x01\n\x15GetAccessTokenRequest\x12\x31\n\ngrant_type\x18\x01 \x01(\x0e\x32\x1d.tigrisdata.auth.v1.GrantType\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x11\n\tclient_id\x18\x03 \x01(\t\x12\x15\n\rclient_secret\x18\x04 \x01(\t\"Y\n\x16GetAccessTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\x05\"N\n\x0eInvitationInfo\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x1f\n\x17invitation_sent_by_name\x18\x03 \x01(\t\"S\n\x18\x43reateInvitationsRequest\x12\x37\n\x0binvitations\x18\x01 \x03(\x0b\x32\".tigrisdata.auth.v1.InvitationInfo\"\x1b\n\x19\x43reateInvitationsResponse\"I\n\x18\x44\x65leteInvitationsRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x13\n\x06status\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_status\"\x1b\n\x19\x44\x65leteInvitationsResponse\"\xb8\x01\n\nInvitation\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x18\n\x10tigris_namespace\x18\x04 \x01(\t\x12\x1d\n\x15tigris_namespace_name\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x17\n\x0f\x63reated_by_name\x18\x07 \x01(\t\x12\x17\n\x0f\x65xpiration_time\x18\x08 \x01(\x03\"8\n\x16ListInvitationsRequest\x12\x13\n\x06status\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_status\"N\n\x17ListInvitationsResponse\x12\x33\n\x0binvitations\x18\x01 \x03(\x0b\x32\x1e.tigrisdata.auth.v1.Invitation\"6\n\x17VerifyInvitationRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\"a\n\x18VerifyInvitationResponse\x12\x18\n\x10tigris_namespace\x18\x01 \x01(\t\x12\x1d\n\x15tigris_namespace_name\x18\x02 \x01(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\"\x12\n\x10ListUsersRequest\"<\n\x11ListUsersResponse\x12\'\n\x05users\x18\x01 \x03(\x0b\x32\x18.tigrisdata.auth.v1.User\"V\n\x04User\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\x03\x12\x0f\n\x07picture\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t*6\n\tGrantType\x12\x11\n\rREFRESH_TOKEN\x10\x00\x12\x16\n\x12\x43LIENT_CREDENTIALS\x10\x01\x32\xc0\t\n\x04\x41uth\x12\xa3\x01\n\x0eGetAccessToken\x12).tigrisdata.auth.v1.GetAccessTokenRequest\x1a*.tigrisdata.auth.v1.GetAccessTokenResponse\":\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/auth/token:\x01*\xbaG\x1e\n\x0e\x41uthentication\x12\x0c\x41\x63\x63\x65ss Token\x12\xdc\x01\n\x11\x43reateInvitations\x12,.tigrisdata.auth.v1.CreateInvitationsRequest\x1a-.tigrisdata.auth.v1.CreateInvitationsResponse\"j\x82\xd3\xe4\x93\x02*\"%/v1/auth/namespace/invitations/create:\x01*\xbaG7\n\nManagement\x12)Creates invitations to join the namespace\x12\xdc\x01\n\x11\x44\x65leteInvitations\x12,.tigrisdata.auth.v1.DeleteInvitationsRequest\x1a-.tigrisdata.auth.v1.DeleteInvitationsResponse\"j\x82\xd3\xe4\x93\x02**%/v1/auth/namespace/invitations/delete:\x01*\xbaG7\n\nManagement\x12)Deletes invitations to join the namespace\x12\xd7\x01\n\x0fListInvitations\x12*.tigrisdata.auth.v1.ListInvitationsRequest\x1a+.tigrisdata.auth.v1.ListInvitationsResponse\"k\x82\xd3\xe4\x93\x02%\x12#/v1/auth/namespace/invitations/list\xbaG=\n\nManagement\x12/Lists all the invitations to join the namespace\x12\xc7\x01\n\x10VerifyInvitation\x12+.tigrisdata.auth.v1.VerifyInvitationRequest\x1a,.tigrisdata.auth.v1.VerifyInvitationResponse\"X\x82\xd3\xe4\x93\x02*\"%/v1/auth/namespace/invitations/verify:\x01*\xbaG%\n\nManagement\x12\x17Verifies the invitation\x12\xaf\x01\n\tListUsers\x12$.tigrisdata.auth.v1.ListUsersRequest\x1a%.tigrisdata.auth.v1.ListUsersResponse\"U\x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/auth/namespace/users\xbaG2\n\nManagement\x12$Lists the users in current namespaceBA\n\x1d\x63om.tigrisdata.db.api.v1.grpcZ github.com/tigrisdata/tigris/apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'server.v1.auth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.tigrisdata.db.api.v1.grpcZ github.com/tigrisdata/tigris/api'
  _AUTH.methods_by_name['GetAccessToken']._options = None
  _AUTH.methods_by_name['GetAccessToken']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/auth/token:\001*\272G\036\n\016Authentication\022\014Access Token'
  _AUTH.methods_by_name['CreateInvitations']._options = None
  _AUTH.methods_by_name['CreateInvitations']._serialized_options = b'\202\323\344\223\002*\"%/v1/auth/namespace/invitations/create:\001*\272G7\n\nManagement\022)Creates invitations to join the namespace'
  _AUTH.methods_by_name['DeleteInvitations']._options = None
  _AUTH.methods_by_name['DeleteInvitations']._serialized_options = b'\202\323\344\223\002**%/v1/auth/namespace/invitations/delete:\001*\272G7\n\nManagement\022)Deletes invitations to join the namespace'
  _AUTH.methods_by_name['ListInvitations']._options = None
  _AUTH.methods_by_name['ListInvitations']._serialized_options = b'\202\323\344\223\002%\022#/v1/auth/namespace/invitations/list\272G=\n\nManagement\022/Lists all the invitations to join the namespace'
  _AUTH.methods_by_name['VerifyInvitation']._options = None
  _AUTH.methods_by_name['VerifyInvitation']._serialized_options = b'\202\323\344\223\002*\"%/v1/auth/namespace/invitations/verify:\001*\272G%\n\nManagement\022\027Verifies the invitation'
  _AUTH.methods_by_name['ListUsers']._options = None
  _AUTH.methods_by_name['ListUsers']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/auth/namespace/users\272G2\n\nManagement\022$Lists the users in current namespace'
  _GRANTTYPE._serialized_start=1284
  _GRANTTYPE._serialized_end=1338
  _GETACCESSTOKENREQUEST._serialized_start=104
  _GETACCESSTOKENREQUEST._serialized_end=243
  _GETACCESSTOKENRESPONSE._serialized_start=245
  _GETACCESSTOKENRESPONSE._serialized_end=334
  _INVITATIONINFO._serialized_start=336
  _INVITATIONINFO._serialized_end=414
  _CREATEINVITATIONSREQUEST._serialized_start=416
  _CREATEINVITATIONSREQUEST._serialized_end=499
  _CREATEINVITATIONSRESPONSE._serialized_start=501
  _CREATEINVITATIONSRESPONSE._serialized_end=528
  _DELETEINVITATIONSREQUEST._serialized_start=530
  _DELETEINVITATIONSREQUEST._serialized_end=603
  _DELETEINVITATIONSRESPONSE._serialized_start=605
  _DELETEINVITATIONSRESPONSE._serialized_end=632
  _INVITATION._serialized_start=635
  _INVITATION._serialized_end=819
  _LISTINVITATIONSREQUEST._serialized_start=821
  _LISTINVITATIONSREQUEST._serialized_end=877
  _LISTINVITATIONSRESPONSE._serialized_start=879
  _LISTINVITATIONSRESPONSE._serialized_end=957
  _VERIFYINVITATIONREQUEST._serialized_start=959
  _VERIFYINVITATIONREQUEST._serialized_end=1013
  _VERIFYINVITATIONRESPONSE._serialized_start=1015
  _VERIFYINVITATIONRESPONSE._serialized_end=1112
  _LISTUSERSREQUEST._serialized_start=1114
  _LISTUSERSREQUEST._serialized_end=1132
  _LISTUSERSRESPONSE._serialized_start=1134
  _LISTUSERSRESPONSE._serialized_end=1194
  _USER._serialized_start=1196
  _USER._serialized_end=1282
  _AUTH._serialized_start=1341
  _AUTH._serialized_end=2557
# @@protoc_insertion_point(module_scope)



from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AdditionalPropertiesItem(_message.Message):
    __slots__ = ["boolean", "schema_or_reference"]
    BOOLEAN_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_OR_REFERENCE_FIELD_NUMBER: _ClassVar[int]
    boolean: bool
    schema_or_reference: SchemaOrReference
    def __init__(self, schema_or_reference: _Optional[_Union[SchemaOrReference, _Mapping]] = ..., boolean: bool = ...) -> None: ...

class Any(_message.Message):
    __slots__ = ["value", "yaml"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    YAML_FIELD_NUMBER: _ClassVar[int]
    value: _any_pb2.Any
    yaml: str
    def __init__(self, value: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., yaml: _Optional[str] = ...) -> None: ...

class AnyOrExpression(_message.Message):
    __slots__ = ["any", "expression"]
    ANY_FIELD_NUMBER: _ClassVar[int]
    EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    any: Any
    expression: Expression
    def __init__(self, any: _Optional[_Union[Any, _Mapping]] = ..., expression: _Optional[_Union[Expression, _Mapping]] = ...) -> None: ...

class Callback(_message.Message):
    __slots__ = ["path", "specification_extension"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    path: _containers.RepeatedCompositeFieldContainer[NamedPathItem]
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    def __init__(self, path: _Optional[_Iterable[_Union[NamedPathItem, _Mapping]]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class CallbackOrReference(_message.Message):
    __slots__ = ["callback", "reference"]
    CALLBACK_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    callback: Callback
    reference: Reference
    def __init__(self, callback: _Optional[_Union[Callback, _Mapping]] = ..., reference: _Optional[_Union[Reference, _Mapping]] = ...) -> None: ...

class CallbacksOrReferences(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedCallbackOrReference]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedCallbackOrReference, _Mapping]]] = ...) -> None: ...

class Components(_message.Message):
    __slots__ = ["callbacks", "examples", "headers", "links", "parameters", "request_bodies", "responses", "schemas", "security_schemes", "specification_extension"]
    CALLBACKS_FIELD_NUMBER: _ClassVar[int]
    EXAMPLES_FIELD_NUMBER: _ClassVar[int]
    HEADERS_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    REQUEST_BODIES_FIELD_NUMBER: _ClassVar[int]
    RESPONSES_FIELD_NUMBER: _ClassVar[int]
    SCHEMAS_FIELD_NUMBER: _ClassVar[int]
    SECURITY_SCHEMES_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    callbacks: CallbacksOrReferences
    examples: ExamplesOrReferences
    headers: HeadersOrReferences
    links: LinksOrReferences
    parameters: ParametersOrReferences
    request_bodies: RequestBodiesOrReferences
    responses: ResponsesOrReferences
    schemas: SchemasOrReferences
    security_schemes: SecuritySchemesOrReferences
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    def __init__(self, schemas: _Optional[_Union[SchemasOrReferences, _Mapping]] = ..., responses: _Optional[_Union[ResponsesOrReferences, _Mapping]] = ..., parameters: _Optional[_Union[ParametersOrReferences, _Mapping]] = ..., examples: _Optional[_Union[ExamplesOrReferences, _Mapping]] = ..., request_bodies: _Optional[_Union[RequestBodiesOrReferences, _Mapping]] = ..., headers: _Optional[_Union[HeadersOrReferences, _Mapping]] = ..., security_schemes: _Optional[_Union[SecuritySchemesOrReferences, _Mapping]] = ..., links: _Optional[_Union[LinksOrReferences, _Mapping]] = ..., callbacks: _Optional[_Union[CallbacksOrReferences, _Mapping]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class Contact(_message.Message):
    __slots__ = ["email", "name", "specification_extension", "url"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    email: str
    name: str
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    url: str
    def __init__(self, name: _Optional[str] = ..., url: _Optional[str] = ..., email: _Optional[str] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class DefaultType(_message.Message):
    __slots__ = ["boolean", "number", "string"]
    BOOLEAN_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    STRING_FIELD_NUMBER: _ClassVar[int]
    boolean: bool
    number: float
    string: str
    def __init__(self, number: _Optional[float] = ..., boolean: bool = ..., string: _Optional[str] = ...) -> None: ...

class Discriminator(_message.Message):
    __slots__ = ["mapping", "property_name", "specification_extension"]
    MAPPING_FIELD_NUMBER: _ClassVar[int]
    PROPERTY_NAME_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    mapping: Strings
    property_name: str
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    def __init__(self, property_name: _Optional[str] = ..., mapping: _Optional[_Union[Strings, _Mapping]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class Document(_message.Message):
    __slots__ = ["components", "external_docs", "info", "openapi", "paths", "security", "servers", "specification_extension", "tags"]
    COMPONENTS_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_DOCS_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    OPENAPI_FIELD_NUMBER: _ClassVar[int]
    PATHS_FIELD_NUMBER: _ClassVar[int]
    SECURITY_FIELD_NUMBER: _ClassVar[int]
    SERVERS_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    components: Components
    external_docs: ExternalDocs
    info: Info
    openapi: str
    paths: Paths
    security: _containers.RepeatedCompositeFieldContainer[SecurityRequirement]
    servers: _containers.RepeatedCompositeFieldContainer[Server]
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    tags: _containers.RepeatedCompositeFieldContainer[Tag]
    def __init__(self, openapi: _Optional[str] = ..., info: _Optional[_Union[Info, _Mapping]] = ..., servers: _Optional[_Iterable[_Union[Server, _Mapping]]] = ..., paths: _Optional[_Union[Paths, _Mapping]] = ..., components: _Optional[_Union[Components, _Mapping]] = ..., security: _Optional[_Iterable[_Union[SecurityRequirement, _Mapping]]] = ..., tags: _Optional[_Iterable[_Union[Tag, _Mapping]]] = ..., external_docs: _Optional[_Union[ExternalDocs, _Mapping]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class Encoding(_message.Message):
    __slots__ = ["allow_reserved", "content_type", "explode", "headers", "specification_extension", "style"]
    ALLOW_RESERVED_FIELD_NUMBER: _ClassVar[int]
    CONTENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    EXPLODE_FIELD_NUMBER: _ClassVar[int]
    HEADERS_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    STYLE_FIELD_NUMBER: _ClassVar[int]
    allow_reserved: bool
    content_type: str
    explode: bool
    headers: HeadersOrReferences
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    style: str
    def __init__(self, content_type: _Optional[str] = ..., headers: _Optional[_Union[HeadersOrReferences, _Mapping]] = ..., style: _Optional[str] = ..., explode: bool = ..., allow_reserved: bool = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class Encodings(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedEncoding]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedEncoding, _Mapping]]] = ...) -> None: ...

class Example(_message.Message):
    __slots__ = ["description", "external_value", "specification_extension", "summary", "value"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_VALUE_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    description: str
    external_value: str
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    summary: str
    value: Any
    def __init__(self, summary: _Optional[str] = ..., description: _Optional[str] = ..., value: _Optional[_Union[Any, _Mapping]] = ..., external_value: _Optional[str] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class ExampleOrReference(_message.Message):
    __slots__ = ["example", "reference"]
    EXAMPLE_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    example: Example
    reference: Reference
    def __init__(self, example: _Optional[_Union[Example, _Mapping]] = ..., reference: _Optional[_Union[Reference, _Mapping]] = ...) -> None: ...

class ExamplesOrReferences(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedExampleOrReference]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedExampleOrReference, _Mapping]]] = ...) -> None: ...

class Expression(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedAny]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class ExternalDocs(_message.Message):
    __slots__ = ["description", "specification_extension", "url"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    description: str
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    url: str
    def __init__(self, description: _Optional[str] = ..., url: _Optional[str] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class Header(_message.Message):
    __slots__ = ["allow_empty_value", "allow_reserved", "content", "deprecated", "description", "example", "examples", "explode", "required", "schema", "specification_extension", "style"]
    ALLOW_EMPTY_VALUE_FIELD_NUMBER: _ClassVar[int]
    ALLOW_RESERVED_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EXAMPLES_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_FIELD_NUMBER: _ClassVar[int]
    EXPLODE_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    STYLE_FIELD_NUMBER: _ClassVar[int]
    allow_empty_value: bool
    allow_reserved: bool
    content: MediaTypes
    deprecated: bool
    description: str
    example: Any
    examples: ExamplesOrReferences
    explode: bool
    required: bool
    schema: SchemaOrReference
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    style: str
    def __init__(self, description: _Optional[str] = ..., required: bool = ..., deprecated: bool = ..., allow_empty_value: bool = ..., style: _Optional[str] = ..., explode: bool = ..., allow_reserved: bool = ..., schema: _Optional[_Union[SchemaOrReference, _Mapping]] = ..., example: _Optional[_Union[Any, _Mapping]] = ..., examples: _Optional[_Union[ExamplesOrReferences, _Mapping]] = ..., content: _Optional[_Union[MediaTypes, _Mapping]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class HeaderOrReference(_message.Message):
    __slots__ = ["header", "reference"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    header: Header
    reference: Reference
    def __init__(self, header: _Optional[_Union[Header, _Mapping]] = ..., reference: _Optional[_Union[Reference, _Mapping]] = ...) -> None: ...

class HeadersOrReferences(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedHeaderOrReference]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedHeaderOrReference, _Mapping]]] = ...) -> None: ...

class Info(_message.Message):
    __slots__ = ["contact", "description", "license", "specification_extension", "summary", "terms_of_service", "title", "version"]
    CONTACT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LICENSE_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    TERMS_OF_SERVICE_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    contact: Contact
    description: str
    license: License
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    summary: str
    terms_of_service: str
    title: str
    version: str
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., terms_of_service: _Optional[str] = ..., contact: _Optional[_Union[Contact, _Mapping]] = ..., license: _Optional[_Union[License, _Mapping]] = ..., version: _Optional[str] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ..., summary: _Optional[str] = ...) -> None: ...

class ItemsItem(_message.Message):
    __slots__ = ["schema_or_reference"]
    SCHEMA_OR_REFERENCE_FIELD_NUMBER: _ClassVar[int]
    schema_or_reference: _containers.RepeatedCompositeFieldContainer[SchemaOrReference]
    def __init__(self, schema_or_reference: _Optional[_Iterable[_Union[SchemaOrReference, _Mapping]]] = ...) -> None: ...

class License(_message.Message):
    __slots__ = ["name", "specification_extension", "url"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    name: str
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    url: str
    def __init__(self, name: _Optional[str] = ..., url: _Optional[str] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class Link(_message.Message):
    __slots__ = ["description", "operation_id", "operation_ref", "parameters", "request_body", "server", "specification_extension"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    OPERATION_ID_FIELD_NUMBER: _ClassVar[int]
    OPERATION_REF_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    REQUEST_BODY_FIELD_NUMBER: _ClassVar[int]
    SERVER_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    description: str
    operation_id: str
    operation_ref: str
    parameters: AnyOrExpression
    request_body: AnyOrExpression
    server: Server
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    def __init__(self, operation_ref: _Optional[str] = ..., operation_id: _Optional[str] = ..., parameters: _Optional[_Union[AnyOrExpression, _Mapping]] = ..., request_body: _Optional[_Union[AnyOrExpression, _Mapping]] = ..., description: _Optional[str] = ..., server: _Optional[_Union[Server, _Mapping]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class LinkOrReference(_message.Message):
    __slots__ = ["link", "reference"]
    LINK_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    link: Link
    reference: Reference
    def __init__(self, link: _Optional[_Union[Link, _Mapping]] = ..., reference: _Optional[_Union[Reference, _Mapping]] = ...) -> None: ...

class LinksOrReferences(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedLinkOrReference]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedLinkOrReference, _Mapping]]] = ...) -> None: ...

class MediaType(_message.Message):
    __slots__ = ["encoding", "example", "examples", "schema", "specification_extension"]
    ENCODING_FIELD_NUMBER: _ClassVar[int]
    EXAMPLES_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    encoding: Encodings
    example: Any
    examples: ExamplesOrReferences
    schema: SchemaOrReference
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    def __init__(self, schema: _Optional[_Union[SchemaOrReference, _Mapping]] = ..., example: _Optional[_Union[Any, _Mapping]] = ..., examples: _Optional[_Union[ExamplesOrReferences, _Mapping]] = ..., encoding: _Optional[_Union[Encodings, _Mapping]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class MediaTypes(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedMediaType]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedMediaType, _Mapping]]] = ...) -> None: ...

class NamedAny(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: Any
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[Any, _Mapping]] = ...) -> None: ...

class NamedCallbackOrReference(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: CallbackOrReference
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[CallbackOrReference, _Mapping]] = ...) -> None: ...

class NamedEncoding(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: Encoding
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[Encoding, _Mapping]] = ...) -> None: ...

class NamedExampleOrReference(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: ExampleOrReference
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[ExampleOrReference, _Mapping]] = ...) -> None: ...

class NamedHeaderOrReference(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: HeaderOrReference
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[HeaderOrReference, _Mapping]] = ...) -> None: ...

class NamedLinkOrReference(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: LinkOrReference
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[LinkOrReference, _Mapping]] = ...) -> None: ...

class NamedMediaType(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: MediaType
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[MediaType, _Mapping]] = ...) -> None: ...

class NamedParameterOrReference(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: ParameterOrReference
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[ParameterOrReference, _Mapping]] = ...) -> None: ...

class NamedPathItem(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: PathItem
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[PathItem, _Mapping]] = ...) -> None: ...

class NamedRequestBodyOrReference(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: RequestBodyOrReference
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[RequestBodyOrReference, _Mapping]] = ...) -> None: ...

class NamedResponseOrReference(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: ResponseOrReference
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[ResponseOrReference, _Mapping]] = ...) -> None: ...

class NamedSchemaOrReference(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: SchemaOrReference
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[SchemaOrReference, _Mapping]] = ...) -> None: ...

class NamedSecuritySchemeOrReference(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: SecuritySchemeOrReference
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[SecuritySchemeOrReference, _Mapping]] = ...) -> None: ...

class NamedServerVariable(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: ServerVariable
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[ServerVariable, _Mapping]] = ...) -> None: ...

class NamedString(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: str
    def __init__(self, name: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class NamedStringArray(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: StringArray
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[StringArray, _Mapping]] = ...) -> None: ...

class OauthFlow(_message.Message):
    __slots__ = ["authorization_url", "refresh_url", "scopes", "specification_extension", "token_url"]
    AUTHORIZATION_URL_FIELD_NUMBER: _ClassVar[int]
    REFRESH_URL_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    TOKEN_URL_FIELD_NUMBER: _ClassVar[int]
    authorization_url: str
    refresh_url: str
    scopes: Strings
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    token_url: str
    def __init__(self, authorization_url: _Optional[str] = ..., token_url: _Optional[str] = ..., refresh_url: _Optional[str] = ..., scopes: _Optional[_Union[Strings, _Mapping]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class OauthFlows(_message.Message):
    __slots__ = ["authorization_code", "client_credentials", "implicit", "password", "specification_extension"]
    AUTHORIZATION_CODE_FIELD_NUMBER: _ClassVar[int]
    CLIENT_CREDENTIALS_FIELD_NUMBER: _ClassVar[int]
    IMPLICIT_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    authorization_code: OauthFlow
    client_credentials: OauthFlow
    implicit: OauthFlow
    password: OauthFlow
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    def __init__(self, implicit: _Optional[_Union[OauthFlow, _Mapping]] = ..., password: _Optional[_Union[OauthFlow, _Mapping]] = ..., client_credentials: _Optional[_Union[OauthFlow, _Mapping]] = ..., authorization_code: _Optional[_Union[OauthFlow, _Mapping]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class Object(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedAny]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class Operation(_message.Message):
    __slots__ = ["callbacks", "deprecated", "description", "external_docs", "operation_id", "parameters", "request_body", "responses", "security", "servers", "specification_extension", "summary", "tags"]
    CALLBACKS_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_DOCS_FIELD_NUMBER: _ClassVar[int]
    OPERATION_ID_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    REQUEST_BODY_FIELD_NUMBER: _ClassVar[int]
    RESPONSES_FIELD_NUMBER: _ClassVar[int]
    SECURITY_FIELD_NUMBER: _ClassVar[int]
    SERVERS_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    callbacks: CallbacksOrReferences
    deprecated: bool
    description: str
    external_docs: ExternalDocs
    operation_id: str
    parameters: _containers.RepeatedCompositeFieldContainer[ParameterOrReference]
    request_body: RequestBodyOrReference
    responses: Responses
    security: _containers.RepeatedCompositeFieldContainer[SecurityRequirement]
    servers: _containers.RepeatedCompositeFieldContainer[Server]
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    summary: str
    tags: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, tags: _Optional[_Iterable[str]] = ..., summary: _Optional[str] = ..., description: _Optional[str] = ..., external_docs: _Optional[_Union[ExternalDocs, _Mapping]] = ..., operation_id: _Optional[str] = ..., parameters: _Optional[_Iterable[_Union[ParameterOrReference, _Mapping]]] = ..., request_body: _Optional[_Union[RequestBodyOrReference, _Mapping]] = ..., responses: _Optional[_Union[Responses, _Mapping]] = ..., callbacks: _Optional[_Union[CallbacksOrReferences, _Mapping]] = ..., deprecated: bool = ..., security: _Optional[_Iterable[_Union[SecurityRequirement, _Mapping]]] = ..., servers: _Optional[_Iterable[_Union[Server, _Mapping]]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class Parameter(_message.Message):
    __slots__ = ["allow_empty_value", "allow_reserved", "content", "deprecated", "description", "example", "examples", "explode", "name", "required", "schema", "specification_extension", "style"]
    ALLOW_EMPTY_VALUE_FIELD_NUMBER: _ClassVar[int]
    ALLOW_RESERVED_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EXAMPLES_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_FIELD_NUMBER: _ClassVar[int]
    EXPLODE_FIELD_NUMBER: _ClassVar[int]
    IN_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    STYLE_FIELD_NUMBER: _ClassVar[int]
    allow_empty_value: bool
    allow_reserved: bool
    content: MediaTypes
    deprecated: bool
    description: str
    example: Any
    examples: ExamplesOrReferences
    explode: bool
    name: str
    required: bool
    schema: SchemaOrReference
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    style: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., required: bool = ..., deprecated: bool = ..., allow_empty_value: bool = ..., style: _Optional[str] = ..., explode: bool = ..., allow_reserved: bool = ..., schema: _Optional[_Union[SchemaOrReference, _Mapping]] = ..., example: _Optional[_Union[Any, _Mapping]] = ..., examples: _Optional[_Union[ExamplesOrReferences, _Mapping]] = ..., content: _Optional[_Union[MediaTypes, _Mapping]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ..., **kwargs) -> None: ...

class ParameterOrReference(_message.Message):
    __slots__ = ["parameter", "reference"]
    PARAMETER_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    parameter: Parameter
    reference: Reference
    def __init__(self, parameter: _Optional[_Union[Parameter, _Mapping]] = ..., reference: _Optional[_Union[Reference, _Mapping]] = ...) -> None: ...

class ParametersOrReferences(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedParameterOrReference]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedParameterOrReference, _Mapping]]] = ...) -> None: ...

class PathItem(_message.Message):
    __slots__ = ["_ref", "delete", "description", "get", "head", "options", "parameters", "patch", "post", "put", "servers", "specification_extension", "summary", "trace"]
    DELETE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    GET_FIELD_NUMBER: _ClassVar[int]
    HEAD_FIELD_NUMBER: _ClassVar[int]
    OPTIONS_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    POST_FIELD_NUMBER: _ClassVar[int]
    PUT_FIELD_NUMBER: _ClassVar[int]
    SERVERS_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    TRACE_FIELD_NUMBER: _ClassVar[int]
    _REF_FIELD_NUMBER: _ClassVar[int]
    _ref: str
    delete: Operation
    description: str
    get: Operation
    head: Operation
    options: Operation
    parameters: _containers.RepeatedCompositeFieldContainer[ParameterOrReference]
    patch: Operation
    post: Operation
    put: Operation
    servers: _containers.RepeatedCompositeFieldContainer[Server]
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    summary: str
    trace: Operation
    def __init__(self, _ref: _Optional[str] = ..., summary: _Optional[str] = ..., description: _Optional[str] = ..., get: _Optional[_Union[Operation, _Mapping]] = ..., put: _Optional[_Union[Operation, _Mapping]] = ..., post: _Optional[_Union[Operation, _Mapping]] = ..., delete: _Optional[_Union[Operation, _Mapping]] = ..., options: _Optional[_Union[Operation, _Mapping]] = ..., head: _Optional[_Union[Operation, _Mapping]] = ..., patch: _Optional[_Union[Operation, _Mapping]] = ..., trace: _Optional[_Union[Operation, _Mapping]] = ..., servers: _Optional[_Iterable[_Union[Server, _Mapping]]] = ..., parameters: _Optional[_Iterable[_Union[ParameterOrReference, _Mapping]]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class Paths(_message.Message):
    __slots__ = ["path", "specification_extension"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    path: _containers.RepeatedCompositeFieldContainer[NamedPathItem]
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    def __init__(self, path: _Optional[_Iterable[_Union[NamedPathItem, _Mapping]]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class Properties(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedSchemaOrReference]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedSchemaOrReference, _Mapping]]] = ...) -> None: ...

class Reference(_message.Message):
    __slots__ = ["_ref", "description", "summary"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    _REF_FIELD_NUMBER: _ClassVar[int]
    _ref: str
    description: str
    summary: str
    def __init__(self, _ref: _Optional[str] = ..., summary: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class RequestBodiesOrReferences(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedRequestBodyOrReference]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedRequestBodyOrReference, _Mapping]]] = ...) -> None: ...

class RequestBody(_message.Message):
    __slots__ = ["content", "description", "required", "specification_extension"]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    content: MediaTypes
    description: str
    required: bool
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    def __init__(self, description: _Optional[str] = ..., content: _Optional[_Union[MediaTypes, _Mapping]] = ..., required: bool = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class RequestBodyOrReference(_message.Message):
    __slots__ = ["reference", "request_body"]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    REQUEST_BODY_FIELD_NUMBER: _ClassVar[int]
    reference: Reference
    request_body: RequestBody
    def __init__(self, request_body: _Optional[_Union[RequestBody, _Mapping]] = ..., reference: _Optional[_Union[Reference, _Mapping]] = ...) -> None: ...

class Response(_message.Message):
    __slots__ = ["content", "description", "headers", "links", "specification_extension"]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    HEADERS_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    content: MediaTypes
    description: str
    headers: HeadersOrReferences
    links: LinksOrReferences
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    def __init__(self, description: _Optional[str] = ..., headers: _Optional[_Union[HeadersOrReferences, _Mapping]] = ..., content: _Optional[_Union[MediaTypes, _Mapping]] = ..., links: _Optional[_Union[LinksOrReferences, _Mapping]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class ResponseOrReference(_message.Message):
    __slots__ = ["reference", "response"]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    reference: Reference
    response: Response
    def __init__(self, response: _Optional[_Union[Response, _Mapping]] = ..., reference: _Optional[_Union[Reference, _Mapping]] = ...) -> None: ...

class Responses(_message.Message):
    __slots__ = ["default", "response_or_reference", "specification_extension"]
    DEFAULT_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_OR_REFERENCE_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    default: ResponseOrReference
    response_or_reference: _containers.RepeatedCompositeFieldContainer[NamedResponseOrReference]
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    def __init__(self, default: _Optional[_Union[ResponseOrReference, _Mapping]] = ..., response_or_reference: _Optional[_Iterable[_Union[NamedResponseOrReference, _Mapping]]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class ResponsesOrReferences(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedResponseOrReference]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedResponseOrReference, _Mapping]]] = ...) -> None: ...

class Schema(_message.Message):
    __slots__ = ["additional_properties", "all_of", "any_of", "default", "deprecated", "description", "discriminator", "enum", "example", "exclusive_maximum", "exclusive_minimum", "external_docs", "format", "items", "max_items", "max_length", "max_properties", "maximum", "min_items", "min_length", "min_properties", "minimum", "multiple_of", "nullable", "one_of", "pattern", "properties", "read_only", "required", "specification_extension", "title", "type", "unique_items", "write_only", "xml"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    ALL_OF_FIELD_NUMBER: _ClassVar[int]
    ANY_OF_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DISCRIMINATOR_FIELD_NUMBER: _ClassVar[int]
    ENUM_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_FIELD_NUMBER: _ClassVar[int]
    EXCLUSIVE_MAXIMUM_FIELD_NUMBER: _ClassVar[int]
    EXCLUSIVE_MINIMUM_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_DOCS_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    MAXIMUM_FIELD_NUMBER: _ClassVar[int]
    MAX_ITEMS_FIELD_NUMBER: _ClassVar[int]
    MAX_LENGTH_FIELD_NUMBER: _ClassVar[int]
    MAX_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    MINIMUM_FIELD_NUMBER: _ClassVar[int]
    MIN_ITEMS_FIELD_NUMBER: _ClassVar[int]
    MIN_LENGTH_FIELD_NUMBER: _ClassVar[int]
    MIN_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    MULTIPLE_OF_FIELD_NUMBER: _ClassVar[int]
    NOT_FIELD_NUMBER: _ClassVar[int]
    NULLABLE_FIELD_NUMBER: _ClassVar[int]
    ONE_OF_FIELD_NUMBER: _ClassVar[int]
    PATTERN_FIELD_NUMBER: _ClassVar[int]
    PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    READ_ONLY_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    UNIQUE_ITEMS_FIELD_NUMBER: _ClassVar[int]
    WRITE_ONLY_FIELD_NUMBER: _ClassVar[int]
    XML_FIELD_NUMBER: _ClassVar[int]
    additional_properties: AdditionalPropertiesItem
    all_of: _containers.RepeatedCompositeFieldContainer[SchemaOrReference]
    any_of: _containers.RepeatedCompositeFieldContainer[SchemaOrReference]
    default: DefaultType
    deprecated: bool
    description: str
    discriminator: Discriminator
    enum: _containers.RepeatedCompositeFieldContainer[Any]
    example: Any
    exclusive_maximum: bool
    exclusive_minimum: bool
    external_docs: ExternalDocs
    format: str
    items: ItemsItem
    max_items: int
    max_length: int
    max_properties: int
    maximum: float
    min_items: int
    min_length: int
    min_properties: int
    minimum: float
    multiple_of: float
    nullable: bool
    one_of: _containers.RepeatedCompositeFieldContainer[SchemaOrReference]
    pattern: str
    properties: Properties
    read_only: bool
    required: _containers.RepeatedScalarFieldContainer[str]
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    title: str
    type: str
    unique_items: bool
    write_only: bool
    xml: Xml
    def __init__(self, nullable: bool = ..., discriminator: _Optional[_Union[Discriminator, _Mapping]] = ..., read_only: bool = ..., write_only: bool = ..., xml: _Optional[_Union[Xml, _Mapping]] = ..., external_docs: _Optional[_Union[ExternalDocs, _Mapping]] = ..., example: _Optional[_Union[Any, _Mapping]] = ..., deprecated: bool = ..., title: _Optional[str] = ..., multiple_of: _Optional[float] = ..., maximum: _Optional[float] = ..., exclusive_maximum: bool = ..., minimum: _Optional[float] = ..., exclusive_minimum: bool = ..., max_length: _Optional[int] = ..., min_length: _Optional[int] = ..., pattern: _Optional[str] = ..., max_items: _Optional[int] = ..., min_items: _Optional[int] = ..., unique_items: bool = ..., max_properties: _Optional[int] = ..., min_properties: _Optional[int] = ..., required: _Optional[_Iterable[str]] = ..., enum: _Optional[_Iterable[_Union[Any, _Mapping]]] = ..., type: _Optional[str] = ..., all_of: _Optional[_Iterable[_Union[SchemaOrReference, _Mapping]]] = ..., one_of: _Optional[_Iterable[_Union[SchemaOrReference, _Mapping]]] = ..., any_of: _Optional[_Iterable[_Union[SchemaOrReference, _Mapping]]] = ..., items: _Optional[_Union[ItemsItem, _Mapping]] = ..., properties: _Optional[_Union[Properties, _Mapping]] = ..., additional_properties: _Optional[_Union[AdditionalPropertiesItem, _Mapping]] = ..., default: _Optional[_Union[DefaultType, _Mapping]] = ..., description: _Optional[str] = ..., format: _Optional[str] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ..., **kwargs) -> None: ...

class SchemaOrReference(_message.Message):
    __slots__ = ["reference", "schema"]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    reference: Reference
    schema: Schema
    def __init__(self, schema: _Optional[_Union[Schema, _Mapping]] = ..., reference: _Optional[_Union[Reference, _Mapping]] = ...) -> None: ...

class SchemasOrReferences(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedSchemaOrReference]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedSchemaOrReference, _Mapping]]] = ...) -> None: ...

class SecurityRequirement(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedStringArray]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedStringArray, _Mapping]]] = ...) -> None: ...

class SecurityScheme(_message.Message):
    __slots__ = ["bearer_format", "description", "flows", "name", "open_id_connect_url", "scheme", "specification_extension", "type"]
    BEARER_FORMAT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    FLOWS_FIELD_NUMBER: _ClassVar[int]
    IN_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OPEN_ID_CONNECT_URL_FIELD_NUMBER: _ClassVar[int]
    SCHEME_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    bearer_format: str
    description: str
    flows: OauthFlows
    name: str
    open_id_connect_url: str
    scheme: str
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    type: str
    def __init__(self, type: _Optional[str] = ..., description: _Optional[str] = ..., name: _Optional[str] = ..., scheme: _Optional[str] = ..., bearer_format: _Optional[str] = ..., flows: _Optional[_Union[OauthFlows, _Mapping]] = ..., open_id_connect_url: _Optional[str] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ..., **kwargs) -> None: ...

class SecuritySchemeOrReference(_message.Message):
    __slots__ = ["reference", "security_scheme"]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    SECURITY_SCHEME_FIELD_NUMBER: _ClassVar[int]
    reference: Reference
    security_scheme: SecurityScheme
    def __init__(self, security_scheme: _Optional[_Union[SecurityScheme, _Mapping]] = ..., reference: _Optional[_Union[Reference, _Mapping]] = ...) -> None: ...

class SecuritySchemesOrReferences(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedSecuritySchemeOrReference]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedSecuritySchemeOrReference, _Mapping]]] = ...) -> None: ...

class Server(_message.Message):
    __slots__ = ["description", "specification_extension", "url", "variables"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    VARIABLES_FIELD_NUMBER: _ClassVar[int]
    description: str
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    url: str
    variables: ServerVariables
    def __init__(self, url: _Optional[str] = ..., description: _Optional[str] = ..., variables: _Optional[_Union[ServerVariables, _Mapping]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class ServerVariable(_message.Message):
    __slots__ = ["default", "description", "enum", "specification_extension"]
    DEFAULT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ENUM_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    default: str
    description: str
    enum: _containers.RepeatedScalarFieldContainer[str]
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    def __init__(self, enum: _Optional[_Iterable[str]] = ..., default: _Optional[str] = ..., description: _Optional[str] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class ServerVariables(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedServerVariable]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedServerVariable, _Mapping]]] = ...) -> None: ...

class SpecificationExtension(_message.Message):
    __slots__ = ["boolean", "number", "string"]
    BOOLEAN_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    STRING_FIELD_NUMBER: _ClassVar[int]
    boolean: bool
    number: float
    string: str
    def __init__(self, number: _Optional[float] = ..., boolean: bool = ..., string: _Optional[str] = ...) -> None: ...

class StringArray(_message.Message):
    __slots__ = ["value"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, value: _Optional[_Iterable[str]] = ...) -> None: ...

class Strings(_message.Message):
    __slots__ = ["additional_properties"]
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    additional_properties: _containers.RepeatedCompositeFieldContainer[NamedString]
    def __init__(self, additional_properties: _Optional[_Iterable[_Union[NamedString, _Mapping]]] = ...) -> None: ...

class Tag(_message.Message):
    __slots__ = ["description", "external_docs", "name", "specification_extension"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_DOCS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    description: str
    external_docs: ExternalDocs
    name: str
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., external_docs: _Optional[_Union[ExternalDocs, _Mapping]] = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...

class Xml(_message.Message):
    __slots__ = ["attribute", "name", "namespace", "prefix", "specification_extension", "wrapped"]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PREFIX_FIELD_NUMBER: _ClassVar[int]
    SPECIFICATION_EXTENSION_FIELD_NUMBER: _ClassVar[int]
    WRAPPED_FIELD_NUMBER: _ClassVar[int]
    attribute: bool
    name: str
    namespace: str
    prefix: str
    specification_extension: _containers.RepeatedCompositeFieldContainer[NamedAny]
    wrapped: bool
    def __init__(self, name: _Optional[str] = ..., namespace: _Optional[str] = ..., prefix: _Optional[str] = ..., attribute: bool = ..., wrapped: bool = ..., specification_extension: _Optional[_Iterable[_Union[NamedAny, _Mapping]]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ...server.v1 import observability_pb2 as server_dot_v1_dot_observability__pb2


class ObservabilityStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.QueryTimeSeriesMetrics = channel.unary_unary(
                '/tigrisdata.observability.v1.Observability/QueryTimeSeriesMetrics',
                request_serializer=server_dot_v1_dot_observability__pb2.QueryTimeSeriesMetricsRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_observability__pb2.QueryTimeSeriesMetricsResponse.FromString,
                )
        self.QuotaLimits = channel.unary_unary(
                '/tigrisdata.observability.v1.Observability/QuotaLimits',
                request_serializer=server_dot_v1_dot_observability__pb2.QuotaLimitsRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_observability__pb2.QuotaLimitsResponse.FromString,
                )
        self.QuotaUsage = channel.unary_unary(
                '/tigrisdata.observability.v1.Observability/QuotaUsage',
                request_serializer=server_dot_v1_dot_observability__pb2.QuotaUsageRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_observability__pb2.QuotaUsageResponse.FromString,
                )
        self.GetInfo = channel.unary_unary(
                '/tigrisdata.observability.v1.Observability/GetInfo',
                request_serializer=server_dot_v1_dot_observability__pb2.GetInfoRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_observability__pb2.GetInfoResponse.FromString,
                )


class ObservabilityServicer(object):
    """Missing associated documentation comment in .proto file."""

    def QueryTimeSeriesMetrics(self, request, context):
        """Queries time series metrics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuotaLimits(self, request, context):
        """Returns current namespace quota limits
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuotaUsage(self, request, context):
        """Returns current namespace quota limits
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInfo(self, request, context):
        """Provides the information about the server. This information includes returning the server version, etc.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ObservabilityServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'QueryTimeSeriesMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryTimeSeriesMetrics,
                    request_deserializer=server_dot_v1_dot_observability__pb2.QueryTimeSeriesMetricsRequest.FromString,
                    response_serializer=server_dot_v1_dot_observability__pb2.QueryTimeSeriesMetricsResponse.SerializeToString,
            ),
            'QuotaLimits': grpc.unary_unary_rpc_method_handler(
                    servicer.QuotaLimits,
                    request_deserializer=server_dot_v1_dot_observability__pb2.QuotaLimitsRequest.FromString,
                    response_serializer=server_dot_v1_dot_observability__pb2.QuotaLimitsResponse.SerializeToString,
            ),
            'QuotaUsage': grpc.unary_unary_rpc_method_handler(
                    servicer.QuotaUsage,
                    request_deserializer=server_dot_v1_dot_observability__pb2.QuotaUsageRequest.FromString,
                    response_serializer=server_dot_v1_dot_observability__pb2.QuotaUsageResponse.SerializeToString,
            ),
            'GetInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInfo,
                    request_deserializer=server_dot_v1_dot_observability__pb2.GetInfoRequest.FromString,
                    response_serializer=server_dot_v1_dot_observability__pb2.GetInfoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tigrisdata.observability.v1.Observability', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Observability(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def QueryTimeSeriesMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.observability.v1.Observability/QueryTimeSeriesMetrics',
            server_dot_v1_dot_observability__pb2.QueryTimeSeriesMetricsRequest.SerializeToString,
            server_dot_v1_dot_observability__pb2.QueryTimeSeriesMetricsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QuotaLimits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.observability.v1.Observability/QuotaLimits',
            server_dot_v1_dot_observability__pb2.QuotaLimitsRequest.SerializeToString,
            server_dot_v1_dot_observability__pb2.QuotaLimitsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QuotaUsage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.observability.v1.Observability/QuotaUsage',
            server_dot_v1_dot_observability__pb2.QuotaUsageRequest.SerializeToString,
            server_dot_v1_dot_observability__pb2.QuotaUsageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.observability.v1.Observability/GetInfo',
            server_dot_v1_dot_observability__pb2.GetInfoRequest.SerializeToString,
            server_dot_v1_dot_observability__pb2.GetInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from ...google.api import annotations_pb2 as _annotations_pb2
from ...openapiv3 import annotations_pb2 as _annotations_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

CLIENT_CREDENTIALS: GrantType
DESCRIPTOR: _descriptor.FileDescriptor
REFRESH_TOKEN: GrantType

class CreateInvitationsRequest(_message.Message):
    __slots__ = ["invitations"]
    INVITATIONS_FIELD_NUMBER: _ClassVar[int]
    invitations: _containers.RepeatedCompositeFieldContainer[InvitationInfo]
    def __init__(self, invitations: _Optional[_Iterable[_Union[InvitationInfo, _Mapping]]] = ...) -> None: ...

class CreateInvitationsResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteInvitationsRequest(_message.Message):
    __slots__ = ["email", "status"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    email: str
    status: str
    def __init__(self, email: _Optional[str] = ..., status: _Optional[str] = ...) -> None: ...

class DeleteInvitationsResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetAccessTokenRequest(_message.Message):
    __slots__ = ["client_id", "client_secret", "grant_type", "refresh_token"]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
    GRANT_TYPE_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    client_secret: str
    grant_type: GrantType
    refresh_token: str
    def __init__(self, grant_type: _Optional[_Union[GrantType, str]] = ..., refresh_token: _Optional[str] = ..., client_id: _Optional[str] = ..., client_secret: _Optional[str] = ...) -> None: ...

class GetAccessTokenResponse(_message.Message):
    __slots__ = ["access_token", "expires_in", "refresh_token"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_IN_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    expires_in: int
    refresh_token: str
    def __init__(self, access_token: _Optional[str] = ..., refresh_token: _Optional[str] = ..., expires_in: _Optional[int] = ...) -> None: ...

class Invitation(_message.Message):
    __slots__ = ["created_by", "created_by_name", "email", "expiration_time", "role", "status", "tigris_namespace", "tigris_namespace_name"]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    EXPIRATION_TIME_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TIGRIS_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    TIGRIS_NAMESPACE_NAME_FIELD_NUMBER: _ClassVar[int]
    created_by: str
    created_by_name: str
    email: str
    expiration_time: int
    role: str
    status: str
    tigris_namespace: str
    tigris_namespace_name: str
    def __init__(self, email: _Optional[str] = ..., role: _Optional[str] = ..., status: _Optional[str] = ..., tigris_namespace: _Optional[str] = ..., tigris_namespace_name: _Optional[str] = ..., created_by: _Optional[str] = ..., created_by_name: _Optional[str] = ..., expiration_time: _Optional[int] = ...) -> None: ...

class InvitationInfo(_message.Message):
    __slots__ = ["email", "invitation_sent_by_name", "role"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    INVITATION_SENT_BY_NAME_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    email: str
    invitation_sent_by_name: str
    role: str
    def __init__(self, email: _Optional[str] = ..., role: _Optional[str] = ..., invitation_sent_by_name: _Optional[str] = ...) -> None: ...

class ListInvitationsRequest(_message.Message):
    __slots__ = ["status"]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: str
    def __init__(self, status: _Optional[str] = ...) -> None: ...

class ListInvitationsResponse(_message.Message):
    __slots__ = ["invitations"]
    INVITATIONS_FIELD_NUMBER: _ClassVar[int]
    invitations: _containers.RepeatedCompositeFieldContainer[Invitation]
    def __init__(self, invitations: _Optional[_Iterable[_Union[Invitation, _Mapping]]] = ...) -> None: ...

class ListUsersRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListUsersResponse(_message.Message):
    __slots__ = ["users"]
    USERS_FIELD_NUMBER: _ClassVar[int]
    users: _containers.RepeatedCompositeFieldContainer[User]
    def __init__(self, users: _Optional[_Iterable[_Union[User, _Mapping]]] = ...) -> None: ...

class User(_message.Message):
    __slots__ = ["created_at", "email", "name", "picture", "role"]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PICTURE_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    created_at: int
    email: str
    name: str
    picture: str
    role: str
    def __init__(self, email: _Optional[str] = ..., name: _Optional[str] = ..., created_at: _Optional[int] = ..., picture: _Optional[str] = ..., role: _Optional[str] = ...) -> None: ...

class VerifyInvitationRequest(_message.Message):
    __slots__ = ["code", "email"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    code: str
    email: str
    def __init__(self, email: _Optional[str] = ..., code: _Optional[str] = ...) -> None: ...

class VerifyInvitationResponse(_message.Message):
    __slots__ = ["role", "tigris_namespace", "tigris_namespace_name"]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    TIGRIS_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    TIGRIS_NAMESPACE_NAME_FIELD_NUMBER: _ClassVar[int]
    role: str
    tigris_namespace: str
    tigris_namespace_name: str
    def __init__(self, tigris_namespace: _Optional[str] = ..., tigris_namespace_name: _Optional[str] = ..., role: _Optional[str] = ...) -> None: ...

class GrantType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



import abc
from dataclasses import dataclass
from typing import Dict, Optional, Type

Document: Type[dict] = Dict


@dataclass
class ClientConfig:
    project_name: str = ""
    client_id: Optional[str] = None
    client_secret: Optional[str] = None
    branch: str = ""
    server_url: str = ""


class Serializable(abc.ABC):
    @abc.abstractmethod
    def query(self) -> Dict:
        raise NotImplementedError()


class BaseOperator(abc.ABC):
    @property
    @abc.abstractmethod
    def operator(self):
        raise NotImplementedError()



import base64
import datetime
import json
from typing import Any, Union


class CustomJSONEncoder(json.JSONEncoder):
    def default(self, obj: Any) -> Any:
        if isinstance(obj, datetime.datetime):
            return obj.isoformat()
        return json.JSONEncoder.default(obj)


def obj_to_str(doc: object) -> str:
    return json.dumps(doc, cls=CustomJSONEncoder)


def str_to_bytes(doc_str: str) -> bytes:
    return doc_str.encode("utf-8")


# todo: add date serialization tests
def marshal(doc: object) -> bytes:
    return str_to_bytes(obj_to_str(doc))


def bytes_to_str(b: bytes) -> str:
    return b.decode("utf-8")


def str_to_obj(doc_str: str) -> object:
    return json.loads(doc_str)


# todo: add date deserialization tests
def unmarshal(b: bytes) -> Union[object, dict]:
    return str_to_obj(bytes_to_str(b))


def b64_to_object(b64_str: str) -> object:
    return unmarshal(base64.b64decode(b64_str))


def obj_to_b64(doc: object) -> str:
    return bytes_to_str(base64.b64encode(marshal(doc)))


def schema_to_bytes(schema: dict) -> bytes:
    return marshal(schema)



import os
from typing import Optional

import grpc

from api.generated.server.v1.api_pb2_grpc import TigrisStub
from api.generated.server.v1.search_pb2_grpc import SearchStub
from tigrisdb.auth import AuthGateway
from tigrisdb.database import Database
from tigrisdb.errors import TigrisException
from tigrisdb.search import Search
from tigrisdb.types import ClientConfig


class TigrisClient(object):
    __LOCAL_SERVER = "localhost:8081"

    __tigris_client: TigrisStub
    __search_client: SearchStub
    __config: ClientConfig

    def __init__(self, config: Optional[ClientConfig] = None):
        os.environ["PROTOCOL_BUFFERS_PYTHON_IMPLEMENTATION"] = "python"

        if not config:
            config = ClientConfig()
        self.__config = config
        if not config.server_url:
            config.server_url = os.getenv("TIGRIS_URI", TigrisClient.__LOCAL_SERVER)
        if config.server_url.startswith("https://"):
            config.server_url = config.server_url.replace("https://", "")
        if config.server_url.startswith("http://"):
            config.server_url = config.server_url.replace("http://", "")
        if ":" not in config.server_url:
            config.server_url = f"{config.server_url}:443"

        # initialize rest of config
        if not config.project_name:
            config.project_name = os.getenv("TIGRIS_PROJECT")
        if not config.client_id:
            config.client_id = os.getenv("TIGRIS_CLIENT_ID")
        if not config.client_secret:
            config.client_secret = os.getenv("TIGRIS_CLIENT_SECRET")
        if not config.branch:
            config.branch = os.getenv("TIGRIS_DB_BRANCH", "")

        is_local_dev = any(
            map(
                lambda k: k in config.server_url,
                ["localhost", "127.0.0.1", "tigrisdb-local-server:", "[::1]"],
            )
        )

        if is_local_dev:
            channel = grpc.insecure_channel(config.server_url)
        else:
            auth_gtwy = AuthGateway(config)
            channel_creds = grpc.ssl_channel_credentials()
            call_creds = grpc.metadata_call_credentials(auth_gtwy, name="auth gateway")
            channel = grpc.secure_channel(
                config.server_url,
                grpc.composite_channel_credentials(channel_creds, call_creds),
            )

        try:
            grpc.channel_ready_future(channel).result(timeout=10)
        except grpc.FutureTimeoutError:
            raise TigrisException(f"Connection timed out {config.server_url}")

        self.__tigris_client = TigrisStub(channel)
        self.__search_client = SearchStub(channel)

    @property
    def config(self):
        return self.__config

    def get_db(self):
        return Database(self.__tigris_client, self.__config)

    def get_search(self):
        return Search(self.__search_client, self.__config)
